==> refcodes-remoting-1.2.1-sources.jar: org/refcodes/remoting/InvalidMethodReplyRuntimeException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////
package org.refcodes.remoting;

/**
 * Thrown in case the provided {@link Message} sub-type was not expected and
 * cannot be processed.
 * 
 * TODO: Extend a <code>InterProcessJobProperty</code> mixin.
 */
public class InvalidMethodReplyRuntimeException extends RemotingRuntimeException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param aMessage the a message
	 * @param aErrorCode the a error code
	 */
	public InvalidMethodReplyRuntimeException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param aMessage the a message
	 * @param aCause the a cause
	 * @param aErrorCode the a error code
	 */
	public InvalidMethodReplyRuntimeException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param message the message
	 * @param cause the cause
	 */
	public InvalidMethodReplyRuntimeException( String message, Throwable cause ) {
		super( message, cause );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param message the message
	 */
	public InvalidMethodReplyRuntimeException( String message ) {
		super( message );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param aCause the a cause
	 * @param aErrorCode the a error code
	 */
	public InvalidMethodReplyRuntimeException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param cause the cause
	 */
	public InvalidMethodReplyRuntimeException( Throwable cause ) {
		super( cause );
	}
}

==> refcodes-remoting-1.3.2-sources.jar: org/refcodes/remoting/InvalidMethodReplyRuntimeException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////
package org.refcodes.remoting;

/**
 * Thrown in case the provided {@link Message} sub-type was not expected and
 * cannot be processed.
 */
public class InvalidMethodReplyRuntimeException extends RemotingRuntimeException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public InvalidMethodReplyRuntimeException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public InvalidMethodReplyRuntimeException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param message the message
	 * @param cause the cause
	 */
	public InvalidMethodReplyRuntimeException( String message, Throwable cause ) {
		super( message, cause );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param message the message
	 */
	public InvalidMethodReplyRuntimeException( String message ) {
		super( message );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public InvalidMethodReplyRuntimeException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * Instantiates a new invalid method reply runtime exception.
	 *
	 * @param cause the cause
	 */
	public InvalidMethodReplyRuntimeException( Throwable cause ) {
		super( cause );
	}
}
